## ----eval=FALSE, echo=TRUE-----------------------------------------------
#  ## Enter the full path for the gene expression values in here
#  expData_file_name <- scan(what=" ",  sep="\n")
#  exprs <- read.table(expData_file_name, header=TRUE, sep=",", row.names=1, as.is=TRUE) ## reading the file containing
#  ## gene expression values
#  ## Enter the full path for the experimental design file
#  expDesign_file_name <- scan(what=" ", sep="\n")
#  covrts <- read.table(expDesign_file_name, row.names=1, header=TRUE, sep=",") ##reading the file containing the covariates

## ----eval=TRUE, echo=FALSE-----------------------------------------------
## Install and load  the  packagage to run the workflow
library(ExpressionNormalizationWorkflow)
library(Biobase)

## ----eval=TRUE, echo=FALSE-----------------------------------------------
exprs_path <- system.file("extdata",  "CAD_Expression.csv",   package="ExpressionNormalizationWorkflow")
exprs <- read.table(exprs_path, header=TRUE, sep=",", row.names=1, as.is=TRUE)
## reading the file containing the gene expression values
covrts_path <- system.file("extdata",  "CAD_ExptDsgn.csv",   package="ExpressionNormalizationWorkflow")
covrts <- read.table(covrts_path, row.names=1, header=TRUE, sep=",")
##reading the file containing the covariates
exprs[1:5, 1:5]
covrts[1:5, 1:10]

## ----eval=TRUE-----------------------------------------------------------
inpData <- expSetobj(exprs, covrts)

## ----eval=TRUE-----------------------------------------------------------
cvrts_eff_var <- c("BMI", "Rin", "Ethn", "CAD", "Study")
## Setting the covariates whose  effect size on the data needs to be calculated
pct_thrsh <- 0.6 ## PVCA Threshold Value - a value between 0 & 1
## PVCA Threshold Value is the percentile value of the minimum amount of the variabilities that the selected principal components need to explain
pvcAnaly(inpData, pct_thrsh, cvrts_eff_var) ## PVCA

## ----eval=TRUE-----------------------------------------------------------
biol_var_sva <- "CAD" ## Choosing  a biological variable that is to be used to calculate the surrogate variables
sur_var_obj <- surVarAnaly(inpData, biol_var_sva) ## SVA
inpData_sv <- sur_var_obj$expSetobject
var_names <- c("sv1", "sv2") ## sv1 and sv2 are the newly generated surrogate variables  
pData(inpData_sv)<-conTocat(pData(inpData_sv), var_names) ## discretizing the continuous surrogate variables
View(pData(inpData_sv))
## The SVs and the categorized SVs are appended to the covariate matrix as additional columns

## ----eval=TRUE-----------------------------------------------------------
glm.sv1 <- glm(pData(inpData_sv)[, "sv1"]~pData(inpData_sv)[, "Ethn"]+pData(inpData_sv)[, "BMI"]+pData(inpData_sv)[, "Rin"]  
             +pData(inpData_sv)[, "CAD"]+pData(inpData_sv)[, "Study"]) ## Fitting a generalized linear model
summary(glm.sv1)

## ----eval = TRUE---------------------------------------------------------
glm.sv2 <- glm(pData(inpData_sv)[, "sv2"]~pData(inpData_sv)[, "Ethn"]+pData(inpData_sv)[, "BMI"]+pData(inpData_sv)[, "Rin"]  
             +pData(inpData_sv)[, "CAD"]+pData(inpData_sv)[, "Study"]) ## Fitting a generalized linear model
summary(glm.sv2)

## ----eval=TRUE-----------------------------------------------------------
cvrts_eff_var <- c("BMI", "Ethn", "Rin", "CAD", "sv1_cat", "sv2_cat","Study")
## Setting the covariates whose  effect size on the data needs to be calculated
pct_thrsh <- 0.6 ## PVCA Threshold Value - value between 0 and 1
## PVCA Threshold Value is the percentile value of the minimum amount of the variabilities that the selected principal components need to explain
pvcAnaly(inpData_sv, pct_thrsh, cvrts_eff_var) ## PVCA

## ----eval=TRUE-----------------------------------------------------------
bv <- c("CAD") ## Chose your biological variable covariates
av <- c("Study", "sv1_cat", "sv2_cat") ## Chose your adjustment variable covariates
iv <- c("Array") ## Choose your intensity-dependent adjustment variables
sv_snmObj <- snmAnaly(exprs, pData(inpData_sv), bv, av, iv) ## SNM
sv_snmNorm_data <- sv_snmObj$norm.dat
colnames(sv_snmNorm_data) <- colnames(exprs)
sv_snm_data <- expSetobj(sv_snmNorm_data, pData(inpData_sv)) ## Creating an  expressionSetObject of the normalized
                                                           ## data alongwith the covariates

## ----eval=TRUE-----------------------------------------------------------
cvrts_eff_var <- c("BMI", "Ethn", "Rin", "CAD", "sv1_cat", "sv2_cat","Study")
## covariates whose  effect size on the data needs to be calculated
pct_thrsh <- 0.6 # PVCA Threshold Value - value between 0 and 1
## PVCA Threshold Value is the percentile value of the minimum amount of the variabilities that the selected principal components need to explain
pvcAnaly(sv_snm_data, pct_thrsh, cvrts_eff_var)  ## PVCA

## ----eval=TRUE, echo=FALSE-----------------------------------------------
cvrts_eff_var <- c("BMI", "Rin", "Ethn", "CAD", "Study")
pct_thrsh <- 0.6
pvcAnaly(inpData, pct_thrsh, cvrts_eff_var)

## ----eval = TRUE, echo=FALSE---------------------------------------------
bv <- c("CAD") ## Chose your biological variable covariates
av <- c("Study") ## Chose your adjustment variable covariates
iv <- c("Array") ## Choose your intensity-dependent adjustment variables
snmObj <- snmAnaly(exprs, pData(inpData), bv, av, iv) ## SNM
snmNorm_data <- snmObj$norm.dat
colnames(snmNorm_data) <- colnames(exprs)
snm_data <- expSetobj(snmNorm_data, pData(inpData)) ## Creating an  expressionSetObject of the normalized data
                                                 ## alongwith the exisitng covariates

## ----eval = TRUE, echo=FALSE---------------------------------------------
cvrts_eff_var <- c("BMI", "Rin", "Ethn", "CAD", "Study")
pct_thrsh <- 0.6
pvcAnaly(snm_data, pct_thrsh, cvrts_eff_var)

## ----eval = TRUE---------------------------------------------------------
cvrts_eff_var <- c("BMI", "Ethn", "Rin", "CAD", "sv1_cat", "sv2_cat", "Study")
pct_thrsh <- 0.6
pvcAnaly(sv_snm_data, pct_thrsh, cvrts_eff_var)

